from django.test import TestCase
from django.conf import settings
from s3direct.widgets import S3DirectEditor
from django.contrib.admin.templatetags.admin_static import static


class WidgetsTestCase(TestCase):

    def test_s3direct_widget(self):
        HTML = (
            '<div class="s3direct" data-url="/get_upload_params/tests">'
            '    <a class="link" target="_blank" href="test_value">test_value</a>'
            '    <a class="remove" href="#remove">Remove</a>'
            '    <input type="hidden" value="test_value" id="None" name="test_name" />'
            '    <input type="file" class="fileinput" />'
            '    <div class="progress progress-striped active">'
            '        <div class="bar"></div>'
            '    </div>'
            '</div>'
        )

        editor = S3DirectEditor(upload_to='tests')
        rendered = editor.render('test_name', 'test_value')
        self.assertHTMLEqual(rendered, HTML)

    def test_s3direct_widget_no_upload_to_declared(self):
        HTML = (
            '<div class="s3direct" data-url="/get_upload_params/">'
            '    <a class="link" target="_blank" href="test_value">test_value</a>'
            '    <a class="remove" href="#remove">Remove</a>'
            '    <input type="hidden" value="test_value" id="None" name="test_name" />'
            '    <input type="file" class="fileinput" />'
            '    <div class="progress progress-striped active">'
            '        <div class="bar"></div>'
            '    </div>'
            '</div>'
        )

        editor = S3DirectEditor()
        rendered = editor.render('test_name', 'test_value')
        self.assertHTMLEqual(rendered, HTML)


DEBUG = True
DATABASES = {}
DATABASES['default'] = {'ENGINE': 'django.db.backends.sqlite3'}
SECRET_KEY = 'vaO4Y<g#YRWG8;Md8noiLp>.w(w~q_b=|1`?9<x>0KxA%UB!63'
ROOT_URLCONF = 's3direct.urls'
INSTALLED_APPS = ('s3direct',)
AWS_STORAGE_BUCKET_NAME = 'test_bucket'
AWS_SECRET_ACCESS_KEY = 'test_secret'
AWS_ACCESS_KEY_ID = 'test_key'
S3DIRECT_DIR='s3direct'
S3DIRECT_ENDPOINT='s3-eu-west-1.amazonaws.com'
S3DIRECT_UNIQUE_RENAME=True